#!/bin/sh

name=`basename "$1" ".app"`

prefsname=$(echo "$name" | sed 's/ //g')
prefsname="org.ramon.$prefsname"

prefs="$HOME/Library/Preferences/$prefsname.plist"

if [ ! -f "$prefs" ]; then
	defaults write "$prefsname" position -boolean YES
	defaults write "$prefsname" x -integer 0
	defaults write "$prefsname" y -integer 0
	defaults write "$prefsname" dimensions -boolean YES
	defaults write "$prefsname" width -integer 750
	defaults write "$prefsname" height -integer 600
	defaults write "$prefsname" scroll -boolean NO
fi

position=`defaults read "$prefsname" position`
x=`defaults read "$prefsname" x`
y=`defaults read "$prefsname" y`
dimensions=`defaults read "$prefsname" dimensions`
width=`defaults read "$prefsname" width`
height=`defaults read "$prefsname" height`
scroll=`defaults read "$prefsname" scroll`

# given that float is a new preference we handle it differently.
# in a way that does not require those updating to delete the prefs.
float=`defaults read "$prefsname" float 2>/dev/null`

if [ "$?" != "0" ]; then
	defaults write "$prefsname" float -boolean NO
	float="0"
fi

if [ "$position" == "1" ]; then
arch -i386 /usr/bin/osascript <<EOF
try
	tell application "System Events"
		if UI elements enabled then
			tell process "$name"
				-- move the window
				set the position of window 1 to {$x, $y}
			end tell
		end if
	end tell
end try
EOF
fi

if [ "$dimensions" == "1" ]; then
arch -i386 /usr/bin/osascript <<EOF
try
	tell application "System Events"
		if UI elements enabled then
			tell process "$name"
				-- resize the window
				set the size of window 1 to {$width, $height}
			end tell
		end if
	end tell
end try
EOF
fi

if [ "$#" == 1 ]; then
	cat "$1/Contents/Resources/Instructions.html"
else
	if [[ $2 == http://* ]]; then
		echo "<h1>Wait loading...</h1>"
		echo "<code>$2</code>"
		echo "<meta http-equiv=\"refresh\" content=\"0; url=$2\">"
	elif [ "${2##*.}" == "pdf" ]; then
		echo "<h1>Wait loading...</h1>"
		echo "<code>$2</code>"
		echo "<meta http-equiv=\"refresh\" content=\"0; url=file://localhost/$2\">"
	else
		HTML=`cat "$2" 2>&1`
		if [ $? != 0 ]; then
			HTML=`echo "$2"`
		fi
	fi

	
fi
echo "$HTML" | /usr/bin/iconv -f UTF-8 -t LATIN1 --unicode-subst="&#%u;"

if [ "$scroll" == "1" ]; then
arch -i386 /usr/bin/osascript <<EOF
try
	tell application "System Events"
		if UI elements enabled then
			tell process "$name"
				-- scroll to the bottom of the page
				tell scroll area 1 of group 1 of window 1
					if (count of (value of attribute "AXChildren")) = 3 then
						set value of value indicator 1 of scroll bar 2 to 1
					else
						set value of value indicator 1 of scroll bar 1 to 1
					end if
				end tell
			end tell
		end if
	end tell
end try
EOF
fi

if [ "$float" == "1" ]; then
arch -i386 /usr/bin/osascript <<EOF
tell application "System Events"
	repeat until (get name of every application process) does not contain "$name"
		try
			if not frontmost of process "$name" then
				activate application "$name"
			end if
			delay 0.5
		end try
	end repeat
end tell
EOF
fi
